==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/cs_cz/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Přidat';
$lang['AdminDepartments.edit.text_delete'] = 'Odstranit';
$lang['AdminDepartments.edit.heading_default'] = 'Výchozí';
$lang['AdminDepartments.edit.heading_value'] = 'Hodnota';
$lang['AdminDepartments.edit.heading_name'] = 'Název';
$lang['AdminDepartments.edit.heading_options'] = 'Možnosti';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Automatické mazání';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Šifrované';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klient může přidat';
$lang['AdminDepartments.edit.heading_step'] = 'Krok';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Typ';
$lang['AdminDepartments.edit.heading_visibility'] = 'Viditelnost';
$lang['AdminDepartments.edit.heading_description'] = 'Popis';
$lang['AdminDepartments.edit.heading_label'] = 'Štítek';
$lang['AdminDepartments.edit.no_results'] = 'V tomto oddělení nejsou žádná vlastní pole.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Opravdu chcete toto vlastní pole odstranit? Všechna data spojená s tímto polem budou odstraněna. Pokud chcete toto pole skrýt a zachovat data, změňte jeho viditelnost na Pouze pro zaměstnance.';
$lang['AdminDepartments.edit.field_add_field'] = 'Přidat pole';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Upravit oddělení';
$lang['AdminDepartments.edit.field_status'] = 'Stav';
$lang['AdminDepartments.edit.field_response_id'] = 'Automatické uzavření tipu';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Odesílání připomenutí k tipům s prioritou';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Odesílání připomenutí k tipům se stavem';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatické zasílání připomenutí letenek';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Automatické mazání tipů';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Automatické zavírání tipů';
$lang['AdminDepartments.edit.field_port'] = 'Přístav';
$lang['AdminDepartments.edit.field_pass'] = 'Předat';
$lang['AdminDepartments.edit.field_user'] = 'Uživatel';
$lang['AdminDepartments.edit.field_host'] = 'Hostitel';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Označit zprávy jako';
$lang['AdminDepartments.edit.field_box_name'] = 'Název boxu';
$lang['AdminDepartments.edit.field_security'] = 'Zabezpečení';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Maximální velikost přílohy';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Podporované typy příloh';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Zahrnutí podporovaných příloh do upozornění na tiket';
$lang['AdminDepartments.edit.field_default_priority'] = 'Výchozí priorita';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfigurace potrubí';
$lang['AdminDepartments.edit.field_method'] = 'Zpracování e-mailů';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatický přechod stavu tiketu na odpověď správce';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Odesílání e-mailů s automatickou odpovědí na nové letenky';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Přepsání adresy from nastavené v šablonách e-mailů e-mailovou adresou nastavenou pro toto oddělení.';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Vyžadovat ověření člověkem pro neověřené uživatele';
$lang['AdminDepartments.edit.field_clients_only'] = 'Povolit otevírání tiketů nebo odpovídání na ně pouze klientům';
$lang['AdminDepartments.edit.field_description'] = 'Popis';
$lang['AdminDepartments.edit.field_name'] = 'Název';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Vlastní pole';
$lang['AdminDepartments.edit.tab_general'] = 'Obecné';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Upravit oddělení';
$lang['AdminDepartments.add.text_add'] = 'Přidat';
$lang['AdminDepartments.add.text_delete'] = 'Odstranit';
$lang['AdminDepartments.add.heading_default'] = 'Výchozí';
$lang['AdminDepartments.add.heading_value'] = 'Hodnota';
$lang['AdminDepartments.add.heading_name'] = 'Název';
$lang['AdminDepartments.add.heading_options'] = 'Možnosti';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Automatické mazání';
$lang['AdminDepartments.add.heading_encrypted'] = 'Šifrované';
$lang['AdminDepartments.add.heading_client_add'] = 'Klient může přidat';
$lang['AdminDepartments.add.heading_step'] = 'Krok';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Typ';
$lang['AdminDepartments.add.heading_visibility'] = 'Viditelnost';
$lang['AdminDepartments.add.heading_description'] = 'Popis';
$lang['AdminDepartments.add.heading_label'] = 'Štítek';
$lang['AdminDepartments.add.field_add_field'] = 'Přidat pole';
$lang['AdminDepartments.add.field_addsubmit'] = 'Přidat oddělení';
$lang['AdminDepartments.add.field_status'] = 'Stav';
$lang['AdminDepartments.add.field_response_id'] = 'Automatické uzavření tipu';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Odesílání připomenutí k tipům s prioritou';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Odesílání připomenutí k tipům se stavem';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatické zasílání připomenutí letenek';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Automatické mazání tipů';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Automatické zavírání tipů';
$lang['AdminDepartments.add.field_port'] = 'Přístav';
$lang['AdminDepartments.add.field_pass'] = 'Předat';
$lang['AdminDepartments.add.field_user'] = 'Uživatel';
$lang['AdminDepartments.add.field_host'] = 'Hostitel';
$lang['AdminDepartments.add.field_mark_messages'] = 'Označit zprávy jako';
$lang['AdminDepartments.add.field_box_name'] = 'Název boxu';
$lang['AdminDepartments.add.field_security'] = 'Zabezpečení';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Maximální velikost přílohy';
$lang['AdminDepartments.add.field_attachment_types'] = 'Podporované typy příloh';
$lang['AdminDepartments.add.field_include_attachments'] = 'Zahrnutí podporovaných příloh do upozornění na tiket';
$lang['AdminDepartments.add.field_default_priority'] = 'Výchozí priorita';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfigurace potrubí';
$lang['AdminDepartments.add.field_method'] = 'Zpracování e-mailů';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatický přechod stavu tiketu na odpověď správce';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Odesílání e-mailů s automatickou odpovědí na nové letenky';
$lang['AdminDepartments.add.field_override_from_email'] = 'Přepsání adresy from nastavené v šablonách e-mailů e-mailovou adresou nastavenou pro toto oddělení.';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Vyžadovat ověření člověkem pro neověřené uživatele';
$lang['AdminDepartments.add.field_clients_only'] = 'Povolit otevírání tiketů nebo odpovídání na ně pouze klientům';
$lang['AdminDepartments.add.field_description'] = 'Popis';
$lang['AdminDepartments.add.field_name'] = 'Název';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Vlastní pole';
$lang['AdminDepartments.add.tab_general'] = 'Obecné';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Přidat oddělení';
$lang['AdminDepartments.!text.remove_response'] = 'Odstranění adresy';
$lang['AdminDepartments.!text.no_selected_response'] = 'Není vybrána žádná reakce automatického zavírání.';
$lang['AdminDepartments.!text.add_response'] = 'Nastavení předdefinované odpovědi automatického zavírání';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Pokud je tip uzavřen, údaje pole se automaticky vymažou. Údaje již nebudou pro zaměstnance viditelné.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Zda může klient pole odeslat, pokud je false, klient bude moci pole pouze číst.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maximální velikost přílohy v MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Seznam podporovaných přípon oddělených čárkou (např. zip,jpg,png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Poštovní servery mají omezení týkající se velikosti příloh a typů souborů. Abyste snížili riziko odmítnutí e-mailu, uveďte omezení typu a velikosti příloh. Chcete-li mít jistotu, že klient ví o přílohách, které nebyly zahrnuty, použijte v oznámeních o tiketech značku {ticket.reply_has_attachments}.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Změní stav na %1$s, když zaměstnanec odpoví.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Zrušení zaškrtnutí tohoto políčka znamená, že nové tikety vytvořené pro toto oddělení (e-mailem nebo klientem) nebudou zasílat klientovi nebo zaměstnancům oznámení o odpovědi prostřednictvím e-mailu Přijatý tiket, resp. e-mailu Aktualizovaný tiket pro zaměstnance.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'U všech tipů s jiným stavem než %1$s bude druhé části odeslána upomínka, pokud do zvolené doby neodpoví.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Všechny tipy se stavem %1$s budou po uplynutí zvolené doby automaticky smazány.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Všechny tipy s jiným stavem než %1$s, na které naposledy odpověděl zaměstnanec, budou automaticky uzavřeny, pokud na ně během zvolené doby nikdo neodpověděl.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Nastavte cestu k pipingu podle obrázku, ale nezapomeňte použít správnou cestu k PHP na vašem serveru. Ujistěte se, že je soubor pipe.php spustitelný. Možná budete muset také upravit soubor pipe.php tak, aby obsahoval hashbang na řádku 1, který by vypadal následovně: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'V tomto oddělení nejsou přiděleni žádní zaměstnanci.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Zaměstnanci';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Přidělený personál';
$lang['AdminDepartments.index.no_results'] = 'Neexistují žádná oddělení.';
$lang['AdminDepartments.index.confirm_delete'] = 'Oddělení s přiřazenými tipy nelze smazat, dokud nejsou všechny tipy přiřazeny jinému oddělení. Opravdu chcete toto oddělení odstranit?';
$lang['AdminDepartments.index.option_delete'] = 'Odstranit';
$lang['AdminDepartments.index.option_edit'] = 'Upravit';
$lang['AdminDepartments.index.heading_options'] = 'Možnosti';
$lang['AdminDepartments.index.heading_default_priority'] = 'Výchozí priorita';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Přidělený personál';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Popis';
$lang['AdminDepartments.index.heading_name'] = 'Název';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Oddělení';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Přidat oddělení';
$lang['AdminDepartments.edit.page_title'] = 'Správce podpory > Oddělení > Upravit oddělení';
$lang['AdminDepartments.add.page_title'] = 'Správce podpory > Oddělení > Přidat oddělení';
$lang['AdminDepartments.index.page_title'] = 'Správce podpory > Oddělení';
$lang['AdminDepartments.!success.department_deleted'] = 'Oddělení %1$s bylo úspěšně smazáno.';
$lang['AdminDepartments.!success.department_updated'] = 'Oddělení %1$s bylo úspěšně aktualizováno.';
$lang['AdminDepartments.!success.department_created'] = 'Oddělení %1$s bylo úspěšně vytvořeno.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/cs_cz/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Přidat';
$lang['AdminDepartments.edit.text_delete'] = 'Odstranit';
$lang['AdminDepartments.edit.heading_default'] = 'Výchozí';
$lang['AdminDepartments.edit.heading_value'] = 'Hodnota';
$lang['AdminDepartments.edit.heading_name'] = 'Název';
$lang['AdminDepartments.edit.heading_options'] = 'Možnosti';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Automatické mazání';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Šifrované';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klient může přidat';
$lang['AdminDepartments.edit.heading_step'] = 'Krok';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Typ';
$lang['AdminDepartments.edit.heading_visibility'] = 'Viditelnost';
$lang['AdminDepartments.edit.heading_description'] = 'Popis';
$lang['AdminDepartments.edit.heading_label'] = 'Štítek';
$lang['AdminDepartments.edit.no_results'] = 'V tomto oddělení nejsou žádná vlastní pole.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Opravdu chcete toto vlastní pole odstranit? Všechna data spojená s tímto polem budou odstraněna. Pokud chcete toto pole skrýt a zachovat data, změňte jeho viditelnost na Pouze pro zaměstnance.';
$lang['AdminDepartments.edit.field_add_field'] = 'Přidat pole';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Upravit oddělení';
$lang['AdminDepartments.edit.field_status'] = 'Stav';
$lang['AdminDepartments.edit.field_response_id'] = 'Automatické uzavření tipu';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Odesílání připomenutí k tipům s prioritou';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Odesílání připomenutí k tipům se stavem';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatické zasílání připomenutí letenek';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Automatické mazání tipů';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Automatické zavírání tipů';
$lang['AdminDepartments.edit.field_port'] = 'Přístav';
$lang['AdminDepartments.edit.field_pass'] = 'Předat';
$lang['AdminDepartments.edit.field_user'] = 'Uživatel';
$lang['AdminDepartments.edit.field_host'] = 'Hostitel';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Označit zprávy jako';
$lang['AdminDepartments.edit.field_box_name'] = 'Název boxu';
$lang['AdminDepartments.edit.field_security'] = 'Zabezpečení';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Maximální velikost přílohy';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Podporované typy příloh';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Zahrnutí podporovaných příloh do upozornění na tiket';
$lang['AdminDepartments.edit.field_default_priority'] = 'Výchozí priorita';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfigurace potrubí';
$lang['AdminDepartments.edit.field_method'] = 'Zpracování e-mailů';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatický přechod stavu tiketu na odpověď správce';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Odesílání e-mailů s automatickou odpovědí na nové letenky';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Přepsání adresy from nastavené v šablonách e-mailů e-mailovou adresou nastavenou pro toto oddělení.';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Vyžadovat ověření člověkem pro neověřené uživatele';
$lang['AdminDepartments.edit.field_clients_only'] = 'Povolit otevírání tiketů nebo odpovídání na ně pouze klientům';
$lang['AdminDepartments.edit.field_description'] = 'Popis';
$lang['AdminDepartments.edit.field_name'] = 'Název';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Vlastní pole';
$lang['AdminDepartments.edit.tab_general'] = 'Obecné';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Upravit oddělení';
$lang['AdminDepartments.add.text_add'] = 'Přidat';
$lang['AdminDepartments.add.text_delete'] = 'Odstranit';
$lang['AdminDepartments.add.heading_default'] = 'Výchozí';
$lang['AdminDepartments.add.heading_value'] = 'Hodnota';
$lang['AdminDepartments.add.heading_name'] = 'Název';
$lang['AdminDepartments.add.heading_options'] = 'Možnosti';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Automatické mazání';
$lang['AdminDepartments.add.heading_encrypted'] = 'Šifrované';
$lang['AdminDepartments.add.heading_client_add'] = 'Klient může přidat';
$lang['AdminDepartments.add.heading_step'] = 'Krok';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Typ';
$lang['AdminDepartments.add.heading_visibility'] = 'Viditelnost';
$lang['AdminDepartments.add.heading_description'] = 'Popis';
$lang['AdminDepartments.add.heading_label'] = 'Štítek';
$lang['AdminDepartments.add.field_add_field'] = 'Přidat pole';
$lang['AdminDepartments.add.field_addsubmit'] = 'Přidat oddělení';
$lang['AdminDepartments.add.field_status'] = 'Stav';
$lang['AdminDepartments.add.field_response_id'] = 'Automatické uzavření tipu';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Odesílání připomenutí k tipům s prioritou';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Odesílání připomenutí k tipům se stavem';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatické zasílání připomenutí letenek';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Automatické mazání tipů';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Automatické zavírání tipů';
$lang['AdminDepartments.add.field_port'] = 'Přístav';
$lang['AdminDepartments.add.field_pass'] = 'Předat';
$lang['AdminDepartments.add.field_user'] = 'Uživatel';
$lang['AdminDepartments.add.field_host'] = 'Hostitel';
$lang['AdminDepartments.add.field_mark_messages'] = 'Označit zprávy jako';
$lang['AdminDepartments.add.field_box_name'] = 'Název boxu';
$lang['AdminDepartments.add.field_security'] = 'Zabezpečení';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Maximální velikost přílohy';
$lang['AdminDepartments.add.field_attachment_types'] = 'Podporované typy příloh';
$lang['AdminDepartments.add.field_include_attachments'] = 'Zahrnutí podporovaných příloh do upozornění na tiket';
$lang['AdminDepartments.add.field_default_priority'] = 'Výchozí priorita';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfigurace potrubí';
$lang['AdminDepartments.add.field_method'] = 'Zpracování e-mailů';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatický přechod stavu tiketu na odpověď správce';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Odesílání e-mailů s automatickou odpovědí na nové letenky';
$lang['AdminDepartments.add.field_override_from_email'] = 'Přepsání adresy from nastavené v šablonách e-mailů e-mailovou adresou nastavenou pro toto oddělení.';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Vyžadovat ověření člověkem pro neověřené uživatele';
$lang['AdminDepartments.add.field_clients_only'] = 'Povolit otevírání tiketů nebo odpovídání na ně pouze klientům';
$lang['AdminDepartments.add.field_description'] = 'Popis';
$lang['AdminDepartments.add.field_name'] = 'Název';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Vlastní pole';
$lang['AdminDepartments.add.tab_general'] = 'Obecné';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Přidat oddělení';
$lang['AdminDepartments.!text.remove_response'] = 'Odstranění adresy';
$lang['AdminDepartments.!text.no_selected_response'] = 'Není vybrána žádná reakce automatického zavírání.';
$lang['AdminDepartments.!text.add_response'] = 'Nastavení předdefinované odpovědi automatického zavírání';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Pokud je tip uzavřen, údaje pole se automaticky vymažou. Údaje již nebudou pro zaměstnance viditelné.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Zda může klient pole odeslat, pokud je false, klient bude moci pole pouze číst.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maximální velikost přílohy v MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Seznam podporovaných přípon oddělených čárkou (např. zip,jpg,png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Poštovní servery mají omezení týkající se velikosti příloh a typů souborů. Abyste snížili riziko odmítnutí e-mailu, uveďte omezení typu a velikosti příloh. Chcete-li mít jistotu, že klient ví o přílohách, které nebyly zahrnuty, použijte v oznámeních o tiketech značku {ticket.reply_has_attachments}.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Změní stav na %1$s, když zaměstnanec odpoví.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Zrušení zaškrtnutí tohoto políčka znamená, že nové tikety vytvořené pro toto oddělení (e-mailem nebo klientem) nebudou zasílat klientovi nebo zaměstnancům oznámení o odpovědi prostřednictvím e-mailu Přijatý tiket, resp. e-mailu Aktualizovaný tiket pro zaměstnance.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'U všech tipů s jiným stavem než %1$s bude druhé části odeslána upomínka, pokud do zvolené doby neodpoví.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Všechny tipy se stavem %1$s budou po uplynutí zvolené doby automaticky smazány.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Všechny tipy s jiným stavem než %1$s, na které naposledy odpověděl zaměstnanec, budou automaticky uzavřeny, pokud na ně během zvolené doby nikdo neodpověděl.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Nastavte cestu k pipingu podle obrázku, ale nezapomeňte použít správnou cestu k PHP na vašem serveru. Ujistěte se, že je soubor pipe.php spustitelný. Možná budete muset také upravit soubor pipe.php tak, aby obsahoval hashbang na řádku 1, který by vypadal následovně: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'V tomto oddělení nejsou přiděleni žádní zaměstnanci.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Zaměstnanci';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Přidělený personál';
$lang['AdminDepartments.index.no_results'] = 'Neexistují žádná oddělení.';
$lang['AdminDepartments.index.confirm_delete'] = 'Oddělení s přiřazenými tipy nelze smazat, dokud nejsou všechny tipy přiřazeny jinému oddělení. Opravdu chcete toto oddělení odstranit?';
$lang['AdminDepartments.index.option_delete'] = 'Odstranit';
$lang['AdminDepartments.index.option_edit'] = 'Upravit';
$lang['AdminDepartments.index.heading_options'] = 'Možnosti';
$lang['AdminDepartments.index.heading_default_priority'] = 'Výchozí priorita';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Přidělený personál';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Popis';
$lang['AdminDepartments.index.heading_name'] = 'Název';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Oddělení';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Přidat oddělení';
$lang['AdminDepartments.edit.page_title'] = 'Správce podpory > Oddělení > Upravit oddělení';
$lang['AdminDepartments.add.page_title'] = 'Správce podpory > Oddělení > Přidat oddělení';
$lang['AdminDepartments.index.page_title'] = 'Správce podpory > Oddělení';
$lang['AdminDepartments.!success.department_deleted'] = 'Oddělení %1$s bylo úspěšně smazáno.';
$lang['AdminDepartments.!success.department_updated'] = 'Oddělení %1$s bylo úspěšně aktualizováno.';
$lang['AdminDepartments.!success.department_created'] = 'Oddělení %1$s bylo úspěšně vytvořeno.';
$lang['AdminDepartments.edit.field_priorities'] = 'Dostupné priority';
$lang['AdminDepartments.add.field_priorities'] = 'Dostupné priority';
$lang['AdminDepartments.edit.field_force_import'] = 'Import síly';
$lang['AdminDepartments.add.field_force_import'] = 'Import síly';
$lang['AdminDepartments.!success.department_imported'] = 'Oddělení %1$s bylo úspěšně importováno.';
